/*
 * $Id$
 *
 * [ Description ]
 * 
 */

#include "Behavioural/Generic/RegisterFile_Multi_Banked/include/Parameters.h"
#include "Behavioural/include/XML.h"
using namespace std;

namespace morpheo                    {
namespace behavioural {
namespace generic {
namespace registerfile_multi_banked {


  string Parameters::print (uint32_t depth)
  {
    log_printf(FUNC,RegisterFile_Multi_Banked,"print","Begin");

    XML xml ("registerfile_multi_banked");

    xml.balise_open("registerfile_multi_banked");
    xml.singleton_begin("nb_port_read "); xml.attribut("value",toString(_nb_port_read )); xml.singleton_end();
    xml.singleton_begin("nb_port_write"); xml.attribut("value",toString(_nb_port_write)); xml.singleton_end();
    xml.singleton_begin("nb_word      "); xml.attribut("value",toString(_nb_word      )); xml.singleton_end();
    xml.singleton_begin("size_word    "); xml.attribut("value",toString(_size_word    )); xml.singleton_end();
    xml.singleton_begin("nb_bank      "); xml.attribut("value",toString(_nb_bank      )); xml.singleton_end();
    xml.balise_close();

    log_printf(FUNC,RegisterFile_Multi_Banked,"print","End");
    
    return xml.get_body(depth);
  };

  ostream& operator<< (ostream& output_stream ,
		       morpheo::behavioural::generic::registerfile_multi_banked::Parameters & x)
  {
    output_stream << x.print(0);
    
    return output_stream;
  };

}; // end namespace registerfile_multi_banked
}; // end namespace generic

}; // end namespace behavioural
}; // end namespace morpheo              
